DeepLinkHandler class

Constructors

DeepLinkHandler({dynamic onDeepLinkDetected(bool)?})

Properties

hashCode → int
The hash code for this object.
no setterinherited
onDeepLinkDetected ↔ dynamic Function(bool)?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
extractSocketIdFromUrl(String input) → String
extractTokenFromUrl(String url) → String
initDeepLinkListener() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

screenshotToken ↔ String
getter/setter pair
socketId ↔ String
getter/setter pair